@@ -1,6 +1,6 @@
 
 CREATE TABLE Options (	
-	OptionKey 	Text COLLATE NOCASE not null,	
+	OptionKey 	Text COLLATE NOCASE PRIMARY KEY not null,
 	OptionValue	Text COLLATE NOCASE
 );
 
