@@ -222,7 +222,6 @@ tracker_ontology_service_add (TrackerService *service,
 	name = tracker_service_get_name (service);
 
 	g_hash_table_insert (service_names,
-			     /* g_utf8_collate_key (name, -1),	*/
 			     g_strdup (name),
 			     g_object_ref (service));
 	g_hash_table_insert (service_ids,
@@ -383,8 +382,6 @@ tracker_ontology_get_service_db_by_name (const gchar *service_str)
 		type = TRACKER_DB_TYPE_EMAIL;
 	} else if (g_str_has_prefix (str, "files")) {
 		type = TRACKER_DB_TYPE_FILES;
-	} else if (g_str_has_prefix (str, "xesam")) {
-		type = TRACKER_DB_TYPE_XESAM;
 	} else {
 		type = TRACKER_DB_TYPE_FILES;
 	}
@@ -625,6 +622,20 @@ tracker_ontology_service_get_key_metadata (const gchar *service_str,
 	return 0;
 }
 
+gint
+tracker_ontology_service_get_key_collate (const gchar *service_str,
+					  const gchar *meta_name)
+{
+	gint		i;
+
+	g_return_val_if_fail (service_str != NULL, 0);
+	g_return_val_if_fail (meta_name != NULL, 0);
+
+	i = tracker_ontology_service_get_key_metadata (service_str, meta_name);
+
+	return ((i < 6) ? i : 0);
+}
+
 gboolean
 tracker_ontology_service_get_show_directories (const gchar *service_str)
 {
