@@ -167,6 +167,7 @@ typedef struct {
 	GString		    *sql_select;
 	GString		    *sql_from;
 	GString		    *sql_where;
+	GString             *sql_group;
 	GString		    *sql_order;
 	gchar		    *service;
 } ParserData;
@@ -360,7 +361,8 @@ static TrackerFieldData *
 add_metadata_field (ParserData	*data,
 		    const gchar *field_name,
 		    gboolean	 is_select,
-		    gboolean	 is_condition)
+		    gboolean	 is_condition,
+		    gboolean     is_order)
 {
 	TrackerFieldData *field_data;
 	gboolean	  field_exists;
@@ -390,11 +392,20 @@ add_metadata_field (ParserData	*data,
 			if (is_select) {
 				if (!tracker_field_data_get_is_select (field_data)) {
 					tracker_field_data_set_is_select (field_data, TRUE);
-					g_string_append_printf (data->sql_select, ", %s",
-								tracker_field_data_get_select_field (field_data));
+					if(tracker_field_data_get_multiple_values(field_data)) {
+						g_string_append_printf (data->sql_select, ", GROUP_CONCAT (%s)",
+									tracker_field_data_get_select_field (field_data));
+					} else {
+						g_string_append_printf (data->sql_select, ", %s",
+									tracker_field_data_get_select_field (field_data));
+					}
 				}
 			}
 
+			if (is_order) {
+				tracker_field_data_set_is_order (field_data, TRUE);
+			}
+
 			break;
 		}
 	}
@@ -409,8 +420,17 @@ add_metadata_field (ParserData	*data,
 		if (field_data) {
 			data->fields = g_slist_prepend (data->fields, field_data);
 			if (is_select) {
-				g_string_append_printf (data->sql_select, ", %s",
-							tracker_field_data_get_select_field (field_data));
+				if(tracker_field_data_get_multiple_values(field_data)) {
+					g_string_append_printf (data->sql_select, ", GROUP_CONCAT (%s)",
+								tracker_field_data_get_select_field (field_data));
+				} else {
+					g_string_append_printf (data->sql_select, ", %s",
+								tracker_field_data_get_select_field (field_data));
+				}
+			}
+
+			if (is_order) {
+				tracker_field_data_set_is_order (field_data, TRUE);
 			}
 		}
 	}
@@ -765,7 +785,7 @@ build_sql (ParserData *data)
 						  state != STATE_END_INTEGER &&
 						  state != STATE_END_FLOAT));
 
-	field_data = add_metadata_field (data, data->current_field, FALSE, TRUE);
+	field_data = add_metadata_field (data, data->current_field, FALSE, TRUE, FALSE);
 
 	if (!field_data) {
 		g_free (avalue);
@@ -810,13 +830,16 @@ build_sql (ParserData *data)
 						where_field,
 						data->current_value);
 		} else {
-			TrackerFieldType data_type;
-
-			data_type = tracker_field_data_get_data_type (field_data);
-
-			g_string_append_printf (str, " (%s = %s) ",
-						where_field,
-						value);
+			if ( !strlen(value) || (strcmp(value, " '' ") == 0) ) {
+				tracker_field_data_set_needs_null (field_data, TRUE);
+				g_string_append_printf (str, " ((%s = '') OR %s IS NULL) ",
+							where_field,
+							where_field);
+			} else {
+				g_string_append_printf (str, " (%s = %s) ",
+							where_field,
+							value);
+			}
 		}
 		break;
 
@@ -1122,11 +1145,11 @@ get_select_header (const char *service)
         case 6:
         case 7:
         case 8:
-                g_string_append_printf (result, " Select DISTINCT S.ID, (S.Path || '%s' || S.Name) as uri, GetServiceName(S.ServiceTypeID) as stype ", G_DIR_SEPARATOR_S);
+                g_string_append_printf (result, " Select DISTINCT (S.Path || '%s' || S.Name) as uri, GetServiceName(S.ServiceTypeID) as stype ", G_DIR_SEPARATOR_S);
                 break;
 
         default :
-                g_string_append_printf (result, " Select DISTINCT S.ID, (S.Path || '%s' || S.Name) as uri, GetServiceName(S.ServiceTypeID) as stype ", G_DIR_SEPARATOR_S);
+                g_string_append_printf (result, " Select DISTINCT (S.Path || '%s' || S.Name) as uri, GetServiceName(S.ServiceTypeID) as stype ", G_DIR_SEPARATOR_S);
                 break;
 	}
 
@@ -1134,6 +1157,34 @@ get_select_header (const char *service)
 
 }
 
+static void
+append_where_header (GString *string, const char *service)
+{
+	int type;
+	
+	type = tracker_ontology_get_service_id_by_name (service);
+
+	/* Sqlite is currently unable to perform any ORDER or GROUP BY on split index, so we try not to split
+	   unless necessary on ServiceType FIXME remove when not needed anymore (ie. fixed in sqlite) */
+
+	switch (type) {
+	case 2:
+		/* FILES */
+	case 12:
+		/* EMAILS */
+		g_string_append_printf (string, " (S.ServiceTypeID in (select TypeId from ServiceTypes where TypeName = '%s' or Parent = '%s')) ", service, service);
+		break;
+	default:
+		g_string_append_printf (string, " (S.ServiceTypeID=%d) ", type);
+	}
+
+	/* only search for enabled items */
+	g_string_append_printf (string, "AND (S.Enabled = 1) ");
+
+	/* only search for items on enabled volumes */
+	g_string_append_printf (string, "AND (S.AuxilaryID = 0 OR S.AuxilaryID IN (SELECT VolumeID FROM Volumes WHERE Enabled = 1)) ");
+}
+
 GQuark
 tracker_rdf_error_quark (void)
 {
@@ -1181,14 +1232,14 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 		for (i = 0; i < field_count; i++) {
 			TrackerFieldData *field_data;
 
-			field_data = add_metadata_field (&data, fields[i], TRUE, FALSE);
+			field_data = add_metadata_field (&data, fields[i], TRUE, FALSE, FALSE);
 
 			if (!field_data) {
 				g_set_error (error,
 					     tracker_rdf_error_quark (),
 					     PARSE_ERROR,
 					     "RDF Query failed, field:'%s' not found",
-					     sort_fields[i]);
+					     fields[i]);
 
 				g_slist_foreach (data.fields,
 						 (GFunc) g_object_unref,
@@ -1216,12 +1267,9 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 					table_name);
 	}
 
-	data.sql_where = g_string_new ("");
+	data.sql_where = g_string_new ("\nWHERE ");
 
-	g_string_append_printf (data.sql_where, "\n WHERE (S.ServiceTypeID in (select TypeId from ServiceTypes where TypeName = '%s' or Parent = '%s')) ", service, service);
-
-	/* only search for items on enabled volumes */
-	g_string_append_printf (data.sql_where, "AND (S.AuxilaryID = 0 OR S.AuxilaryID IN (SELECT VolumeID FROM Volumes WHERE Enabled = 1)) ");
+	append_where_header(data.sql_where, service);
 
 	if (keyword_count > 0) {
 		guint keyword;
@@ -1284,6 +1332,8 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 		g_string_append_printf (data.sql_where, "AND ");
 	}
 
+	data.sql_group = g_string_new (" GROUP BY S.ID ");
+
 	if (limit < 1) {
 		limit = 1024;
 	}
@@ -1311,7 +1361,7 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 		for (i = 0; i < sort_field_count; i++) {
 			TrackerFieldData *field_data;
 
-			field_data = add_metadata_field (&data, sort_fields[i], FALSE, FALSE);
+			field_data = add_metadata_field (&data, sort_fields[i], FALSE, FALSE, TRUE);
 
 			if (!field_data) {
 				g_set_error (error,
@@ -1325,6 +1375,7 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 				g_slist_free (data.fields);
 				g_string_free (data.sql_select, TRUE);
 				g_string_free (data.sql_where, TRUE);
+				g_string_free (data.sql_group, TRUE);
 				g_string_free (data.sql_order, TRUE);
 
 				return NULL;
@@ -1335,7 +1386,7 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 			}
 
 			g_string_append_printf (data.sql_order, "%s %s",
-						tracker_field_data_get_select_field (field_data),
+						tracker_field_data_get_order_field (field_data),
 						sort_desc ? "DESC" : "ASC");
 		}
 	}
@@ -1368,13 +1419,24 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 		g_string_free (data.sql_select, TRUE);
 		g_string_free (data.sql_from, TRUE);
 		g_string_free (data.sql_where, TRUE);
+		g_string_free (data.sql_group, TRUE);
 		g_string_free (data.sql_order, TRUE);
 	} else {
 		GSList *l;
 
 		for (l = data.fields; l; l = l->next) {
 			if (!tracker_field_data_get_is_condition (l->data)) {
-				if (tracker_field_data_get_needs_join (l->data)) {
+				if (tracker_field_data_get_is_select (l->data) &&
+				    tracker_field_data_get_needs_join (l->data)) {
+					g_string_append_printf (data.sql_from,
+								"\n LEFT OUTER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID = %s) ",
+								tracker_field_data_get_table_name (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_id_field (l->data));
+				} else if (tracker_field_data_get_is_order (l->data) &&
+					   tracker_field_data_get_needs_collate (l->data)) {
 					g_string_append_printf (data.sql_from,
 								"\n LEFT OUTER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID = %s) ",
 								tracker_field_data_get_table_name (l->data),
@@ -1388,13 +1450,23 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 
 				related_metadata = tracker_data_schema_metadata_field_get_related_names (iface,
                                                                                                          tracker_field_data_get_field_name (l->data));
-				g_string_append_printf (data.sql_from,
-							"\n INNER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID in (%s)) ",
-							tracker_field_data_get_table_name (l->data),
-							tracker_field_data_get_alias (l->data),
-							tracker_field_data_get_alias (l->data),
-							tracker_field_data_get_alias (l->data),
-							related_metadata);
+				if (tracker_field_data_get_needs_null (l->data)) {
+					g_string_append_printf (data.sql_from,
+								"\n LEFT OUTER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID in (%s)) ",
+								tracker_field_data_get_table_name (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								related_metadata);
+				} else {
+					g_string_append_printf (data.sql_from,
+								"\n INNER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID in (%s)) ",
+								tracker_field_data_get_table_name (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								related_metadata);
+				}
 				g_free (related_metadata);
 			}
 		}
@@ -1405,12 +1477,15 @@ tracker_rdf_query_to_sql (TrackerDBInterface  *iface,
 				      " ",
 				      data.sql_where->str,
 				      " ",
+				      data.sql_group->str,
+				      " ",
 				      data.sql_order->str,
 				      NULL);
 
 		g_string_free (data.sql_select, TRUE);
 		g_string_free (data.sql_from, TRUE);
 		g_string_free (data.sql_where, TRUE);
+		g_string_free (data.sql_group, TRUE);
 		g_string_free (data.sql_order, TRUE);
 	}
 
@@ -1463,14 +1538,10 @@ tracker_rdf_filter_to_sql (TrackerDBInterface *iface,
 
 	data.sql_from = g_string_new ("");
 	data.sql_where = g_string_new ("");
+	append_where_header (data.sql_where, service);
 
 	data.fields = *fields;
 
-	g_string_append_printf (data.sql_where, " (S.ServiceTypeID in (select TypeId from ServiceTypes where TypeName = '%s' or Parent = '%s')) ", service, service);
-
-	/* only search for items on enabled volumes */
-	g_string_append (data.sql_where, "AND (S.AuxilaryID = 0 OR S.AuxilaryID IN (SELECT VolumeID FROM Volumes WHERE Enabled = 1)) ");
-
 	if (strlen (query) >= 10) {
 		g_string_append (data.sql_where, "AND ");
 	}
@@ -1502,7 +1573,17 @@ tracker_rdf_filter_to_sql (TrackerDBInterface *iface,
 
 		for (l = data.fields; l; l = l->next) {
 			if (!tracker_field_data_get_is_condition (l->data)) {
-				if (tracker_field_data_get_needs_join (l->data)) {
+				if (tracker_field_data_get_is_select (l->data) &&
+				    tracker_field_data_get_needs_join (l->data)) {
+					g_string_append_printf (data.sql_from,
+								"\n LEFT OUTER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID = %s) ",
+								tracker_field_data_get_table_name (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_id_field (l->data));
+				} else if (tracker_field_data_get_is_order (l->data) &&
+					   tracker_field_data_get_needs_collate (l->data)) {
 					g_string_append_printf (data.sql_from,
 								"\n LEFT OUTER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID = %s) ",
 								tracker_field_data_get_table_name (l->data),
@@ -1515,14 +1596,25 @@ tracker_rdf_filter_to_sql (TrackerDBInterface *iface,
 				gchar *related_metadata;
 
 				related_metadata = tracker_data_schema_metadata_field_get_related_names (iface,
-                                                                                                         tracker_field_data_get_field_name (l->data));
-				g_string_append_printf (data.sql_from,
-							"\n INNER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID in (%s)) ",
-							tracker_field_data_get_table_name (l->data),
-							tracker_field_data_get_alias (l->data),
-							tracker_field_data_get_alias (l->data),
-							tracker_field_data_get_alias (l->data),
-							related_metadata);
+                                                                        tracker_field_data_get_field_name (l->data));
+				if (tracker_field_data_get_needs_null (l->data)) {
+					g_string_append_printf (data.sql_from,
+								"\n LEFT OUTER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID in (%s)) ",
+								tracker_field_data_get_table_name (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								related_metadata);
+				} else {
+					g_string_append_printf (data.sql_from,
+								"\n INNER JOIN %s %s ON (S.ID = %s.ServiceID and %s.MetaDataID in (%s)) ",
+								tracker_field_data_get_table_name (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								tracker_field_data_get_alias (l->data),
+								related_metadata);
+				}
+
 				g_free (related_metadata);
 			}
 		}
