@@ -38,6 +38,7 @@
 #include <glib/gstdio.h>
 
 #include <libtracker-common/tracker-type-utils.h>
+#include <libtracker-common/tracker-file-utils.h>
 
 #include "tracker-main.h"
 #include "tracker-xmp.h"
@@ -72,6 +73,7 @@ static TagProcessors tag_processors[] = {
 
 static TrackerExtractData data[] = {
 	{ "image/png", extract_png },
+	{ "sketch/png", extract_png },
 	{ NULL, NULL }
 };
 
@@ -141,8 +143,8 @@ static void
 extract_png (const gchar *filename,
 	     GHashTable  *metadata)
 {
-	gint	     fd_png;
-	FILE	    *png;
+	goffset      size;
+	FILE	    *f;
 	png_structp  png_ptr;
 	png_infop    info_ptr;
 	png_infop    end_ptr;
@@ -153,49 +155,45 @@ extract_png (const gchar *filename,
 	gint	     bit_depth, color_type;
 	gint	     interlace_type, compression_type, filter_type;
 
-#if defined(__linux__)
-	if ((fd_png = g_open (filename, (O_RDONLY | O_NOATIME))) == -1) {
-#else
-	if ((fd_png = g_open (filename, O_RDONLY)) == -1) {
-#endif
+	size = tracker_file_get_size (filename);
+
+	if (size < 64) {
 		return;
 	}
 
-	if ((png = fdopen (fd_png, "r"))) {
+	f = tracker_file_open (filename, "r", FALSE); 
+
+	if (f) {
 		png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING,
 						  NULL,
 						  NULL,
 						  NULL);
 		if (!png_ptr) {
-			fclose (png);
+			tracker_file_close (f, FALSE);
 			return;
 		}
 
 		info_ptr = png_create_info_struct (png_ptr);
 		if (!info_ptr) {
 			png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-			fclose (png);
+			tracker_file_close (f, FALSE);
 			return;
 		}
 
 		end_ptr = png_create_info_struct (png_ptr);
-		if (!info_ptr) {
+		if (!end_ptr) {
 			png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-			png_destroy_read_struct (&png_ptr, &end_ptr, NULL);
-			fclose (png);
+			tracker_file_close (f, FALSE);
 			return;
 		}
 
-		if (setjmp(png_jmpbuf(png_ptr))) {
-			png_destroy_read_struct (&png_ptr, &info_ptr,
-						 (png_infopp)NULL);
-			png_destroy_read_struct (&png_ptr, &end_ptr,
-						 (png_infopp)NULL);
-			fclose (png);
+		if (setjmp (png_jmpbuf (png_ptr))) {
+			png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
+			tracker_file_close (f, FALSE);
 			return;
 		}
 
-		png_init_io (png_ptr, png);
+		png_init_io (png_ptr, f);
 		png_read_info (png_ptr, info_ptr);
 
 		if (!png_get_IHDR (png_ptr,
@@ -207,19 +205,19 @@ extract_png (const gchar *filename,
 				   &interlace_type,
 				   &compression_type,
 				   &filter_type)) {
-			png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-			png_destroy_read_struct (&png_ptr, &end_ptr, NULL);
-			fclose (png);
+			png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
+			tracker_file_close (f, FALSE);
 			return;
 		}
 		
 		/* Read the image. FIXME We should be able to skip this step and
 		 * just get the info from the end. This causes some errors atm.
 		 */
-		row_pointers = (png_bytepp) malloc (height * sizeof (png_bytep));		
+		row_pointers = g_new0 (png_bytep, height);
+
 		for (row = 0; row < height; row++) {
 			row_pointers[row] = png_malloc (png_ptr,
-							png_get_rowbytes(png_ptr,info_ptr));
+							png_get_rowbytes (png_ptr,info_ptr));
 		}
 
 		png_read_image (png_ptr, row_pointers);
@@ -227,6 +225,7 @@ extract_png (const gchar *filename,
 		for (row = 0; row < height; row++) {
 			png_free (png_ptr, row_pointers[row]);
 		}
+
  		g_free (row_pointers);
 
 		png_read_end (png_ptr, end_ptr);
@@ -244,26 +243,21 @@ extract_png (const gchar *filename,
 				     tracker_escape_metadata_printf ("%ld", height));
 		
 		/* Check that we have the minimum data. FIXME We should not need to do this */
-
 		if (!g_hash_table_lookup (metadata, "Image:Date")) {
-			struct stat st;
+			gchar *date;
+			guint64 mtime;
 
-			if (g_lstat(filename, &st) >= 0) {
-				gchar *date;
-
-				date = tracker_date_to_string (st.st_mtime);
-
-				g_hash_table_insert (metadata,
-						     g_strdup ("Image:Date"),
-						     tracker_escape_metadata (date));
-				g_free (date);
-			}
+			mtime = tracker_file_get_mtime (filename);
+			date = tracker_date_to_string ((time_t) mtime);
+			
+			g_hash_table_insert (metadata,
+					     g_strdup ("Image:Date"),
+					     tracker_escape_metadata (date));
+			g_free (date);
 		}
 
-		png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-		fclose (png);
-	} else {
-		close (fd_png);
+		png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
+		tracker_file_close (f, FALSE);
 	}
 }
 
