@@ -82,7 +82,7 @@
 
 #define TRACKER_INDEXER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRACKER_TYPE_INDEXER, TrackerIndexerPrivate))
 
-#define FILES_REMAINING_THRESHOLD   10000
+#define FILES_REMAINING_THRESHOLD   1000
 #define MAX_FLUSH_FREQUENCY         60
 #define MIN_FLUSH_FREQUENCY         1
 
@@ -136,6 +136,8 @@ struct TrackerIndexerPrivate {
 
 	GTimer *timer;
 
+	GVolumeMonitor *volume_monitor;
+
 	guint idle_id;
 	guint pause_for_duration_id;
 	guint signal_status_id;
@@ -196,6 +198,7 @@ enum {
 	MODULE_FINISHED,
 	PAUSED,
 	CONTINUED,
+	INDEXING_ERROR,
 	LAST_SIGNAL
 };
 
@@ -211,6 +214,11 @@ static void	state_check	       (TrackerIndexer	    *indexer);
 static void     check_finished         (TrackerIndexer      *indexer,
 					gboolean             interrupted);
 
+static gboolean item_process           (TrackerIndexer      *indexer,
+					PathInfo            *info,
+					const gchar         *dirname,
+					const gchar         *basename);
+
 
 static guint signals[LAST_SIGNAL] = { 0, };
 
@@ -360,7 +368,7 @@ flush_data (TrackerIndexer *indexer)
 	tracker_db_index_flush (indexer->private->file_index);
 	tracker_db_index_flush (indexer->private->email_index);
 
-	if ((indexer->private->state & TRACKER_INDEXER_STATE_STOPPED) != 0) {
+	if ((indexer->private->state & TRACKER_INDEXER_STATE_STOPPED) == 0) {
 		signal_status (indexer, "flush");
 	}
 
@@ -495,6 +503,10 @@ index_flushing_notify_cb (GObject        *object,
 
 	state = indexer->private->state;
 
+	if ((state & TRACKER_INDEXER_STATE_CLEANUP) != 0) {
+		return;
+	}
+
 	if ((state & TRACKER_INDEXER_STATE_STOPPED) != 0 &&
 	    !tracker_db_index_get_flushing (indexer->private->file_index) &&
 	    !tracker_db_index_get_flushing (indexer->private->email_index)) {
@@ -518,6 +530,76 @@ index_overloaded_notify_cb (GObject        *object,
 	}
 }
 
+static void
+index_error_received_cb (TrackerDBIndex *index,
+			 const GError   *error,
+			 TrackerIndexer *indexer)
+{
+	g_signal_emit (indexer, signals[INDEXING_ERROR], 0,
+		       error->message, TRUE);
+}
+
+static void
+check_mount_removal (GQueue   *queue,
+		     GFile    *mount_root,
+		     gboolean  remove_first)
+{
+	GList *list, *next;
+	PathInfo *info;
+
+	if (!queue->head) {
+		/* No elements here */
+		return;
+	}
+
+	list = (remove_first) ? queue->head : queue->head->next;
+
+	while (list) {
+		next = list->next;
+		info = list->data;
+
+		if (g_file_has_prefix (info->file, mount_root) ||
+		    (info->source_file && g_file_has_prefix (info->source_file, mount_root))) {
+			g_queue_delete_link (queue, list);
+			path_info_free (info);
+		}
+
+		list = next;
+	}
+}
+
+static void
+mount_pre_unmount_cb (GVolumeMonitor *volume_monitor,
+		      GMount         *mount,
+		      TrackerIndexer *indexer)
+{
+	TrackerIndexerPrivate *priv;
+	GFile *mount_root;
+	PathInfo *current_info;
+	gchar *uri;
+
+	mount_root = g_mount_get_root (mount);
+	priv = indexer->private;
+
+	uri = g_file_get_uri (mount_root);
+	g_debug ("Pre-unmount event for '%s', removing all child elements to be processed", uri);
+	g_free (uri);
+
+	/* Cancel any future elements in the mount */
+	check_mount_removal (priv->dir_queue, mount_root, TRUE);
+	check_mount_removal (priv->file_queue, mount_root, FALSE);
+
+	/* Now cancel current element if it's also in the mount */
+	current_info = g_queue_peek_head (indexer->private->file_queue);
+
+	if (current_info &&
+	    g_file_has_prefix (current_info->file, mount_root)) {
+		tracker_module_file_cancel (current_info->module_file);
+	}
+
+	g_object_unref (mount_root);
+}
+
 static void
 tracker_indexer_finalize (GObject *object)
 {
@@ -593,6 +675,13 @@ tracker_indexer_finalize (GObject *object)
 	g_queue_foreach (priv->file_queue, (GFunc) path_info_free, NULL);
 	g_queue_free (priv->file_queue);
 
+	if (priv->volume_monitor) {
+		g_signal_handlers_disconnect_by_func (priv->volume_monitor,
+						      mount_pre_unmount_cb,
+						      object);
+		g_object_unref (priv->volume_monitor);
+	}
+
 	G_OBJECT_CLASS (tracker_indexer_parent_class)->finalize (object);
 }
 
@@ -698,6 +787,15 @@ tracker_indexer_class_init (TrackerIndexerClass *class)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_STRING);
+	signals[INDEXING_ERROR] =
+		g_signal_new ("indexing-error",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (TrackerIndexerClass, indexing_error),
+			      NULL, NULL,
+			      tracker_marshal_VOID__STRING_BOOL,
+			      G_TYPE_NONE,
+			      2, G_TYPE_STRING, G_TYPE_BOOLEAN);
 
 	g_object_class_install_property (object_class,
 					 PROP_RUNNING,
@@ -853,6 +951,9 @@ cleanup_task_start (TrackerIndexer *indexer)
 		/* Open indexes */
 		tracker_db_index_open (indexer->private->file_index);
 		tracker_db_index_open (indexer->private->email_index);
+
+		/* Push all items in thumbnail queue to the thumbnailer */
+		tracker_thumbnailer_queue_send ();
 	}
 }
 
@@ -963,6 +1064,8 @@ tracker_indexer_init (TrackerIndexer *indexer)
 			  G_CALLBACK (index_flushing_notify_cb), indexer);
 	g_signal_connect (priv->file_index, "notify::overloaded",
 			  G_CALLBACK (index_overloaded_notify_cb), indexer);
+	g_signal_connect (priv->file_index, "error-received",
+			  G_CALLBACK (index_error_received_cb), indexer);
 
 	lindex = tracker_db_index_manager_get_index (TRACKER_DB_INDEX_EMAIL);
 	priv->email_index = g_object_ref (lindex);
@@ -971,6 +1074,8 @@ tracker_indexer_init (TrackerIndexer *indexer)
 			  G_CALLBACK (index_flushing_notify_cb), indexer);
 	g_signal_connect (priv->email_index, "notify::overloaded",
 			  G_CALLBACK (index_overloaded_notify_cb), indexer);
+	g_signal_connect (priv->email_index, "error-received",
+			  G_CALLBACK (index_error_received_cb), indexer);
 
 	/* Set up databases, these pointers are mostly used to
 	 * start/stop transactions, since TrackerDBManager treats
@@ -984,6 +1089,11 @@ tracker_indexer_init (TrackerIndexer *indexer)
 	priv->email_metadata = tracker_db_manager_get_db_interface (TRACKER_DB_EMAIL_METADATA);
 	priv->email_contents = tracker_db_manager_get_db_interface (TRACKER_DB_EMAIL_CONTENTS);
 
+	/* Set up volume monitor */
+	priv->volume_monitor = g_volume_monitor_get ();
+	g_signal_connect (priv->volume_monitor, "mount-pre-unmount",
+			  G_CALLBACK (mount_pre_unmount_cb), indexer);
+
 	/* Set up idle handler to process files/directories */
 	state_check (indexer);
 }
@@ -1470,7 +1580,7 @@ generate_item_thumbnail (TrackerIndexer        *indexer,
 		file = g_file_new_for_path (path);
 		uri = g_file_get_uri (file);
 
-		tracker_thumbnailer_get_file_thumbnail (uri, mime_type);
+		tracker_thumbnailer_queue_file (uri, mime_type);
 
 		g_object_unref (file);
 		g_free (uri);
@@ -1482,10 +1592,10 @@ item_add_or_update (TrackerIndexer        *indexer,
 		    PathInfo              *info,
 		    const gchar           *dirname,
 		    const gchar           *basename,
-		    TrackerModuleMetadata *metadata)
+		    TrackerModuleMetadata *metadata,
+		    const gchar           *text)
 {
 	TrackerService *service;
-	gchar *text;
 	guint32 id;
 	gchar *mount_point = NULL;
 	gchar *service_path;
@@ -1499,7 +1609,6 @@ item_add_or_update (TrackerIndexer        *indexer,
 	if (tracker_data_query_service_exists (service, dirname, basename, &id, NULL)) {
 		TrackerDataMetadata *old_metadata_emb, *old_metadata_non_emb;
 		gchar *old_text;
-		gchar *new_text;
 
 		if (tracker_module_file_get_flags (info->module_file) & TRACKER_FILE_CONTENTS_STATIC) {
 			/* According to the module, the metadata can't change for this item */
@@ -1538,9 +1647,8 @@ item_add_or_update (TrackerIndexer        *indexer,
 		 * difference and add the words.
 		 */
 		old_text = tracker_data_query_content (service, id);
-		new_text = tracker_module_file_get_text (info->module_file);
 
-		item_update_content (indexer, service, id, old_text, new_text);
+		item_update_content (indexer, service, id, old_text, text);
 
 		if (strcmp (tracker_service_get_name (service), "Folders") == 0) {
 			gchar *path;
@@ -1556,7 +1664,6 @@ item_add_or_update (TrackerIndexer        *indexer,
 		}
 
 		g_free (old_text);
-		g_free (new_text);
 		tracker_data_metadata_free (old_metadata_emb);
 		tracker_data_metadata_free (old_metadata_non_emb);
 	} else {
@@ -1578,8 +1685,6 @@ item_add_or_update (TrackerIndexer        *indexer,
 
 		index_metadata (indexer, id, service, metadata);
 
-		text = tracker_module_file_get_text (info->module_file);
-
 		if (text) {
 			/* Save in the index */
 			index_text_with_parsing (indexer,
@@ -1590,7 +1695,6 @@ item_add_or_update (TrackerIndexer        *indexer,
 
 			/* Save in the DB */
 			tracker_data_update_set_content (service, id, text);
-			g_free (text);
 		}
 
 		g_hash_table_destroy (data);
@@ -1605,6 +1709,7 @@ item_add_or_update (TrackerIndexer        *indexer,
 				     basename, 
 				     NULL);
 
+#ifdef HAVE_HAL
 	if (tracker_hal_path_is_on_removable_device (indexer->private->hal,
 						     service_path, 
 						     &mount_point,
@@ -1616,7 +1721,7 @@ item_add_or_update (TrackerIndexer        *indexer,
 						       tracker_service_get_name (service),
 						       metadata);
 	}
-
+#endif
 	g_free (mount_point);
 	g_free (service_path);
 }
@@ -1685,6 +1790,7 @@ update_moved_item_removable_device (TrackerIndexer *indexer,
 	path = g_file_get_path (file);
 	source_path = g_file_get_path (source_file);
 
+#ifdef HAVE_HAL
 	if (tracker_hal_path_is_on_removable_device (indexer->private->hal,
 						     source_path,
 						     &mount_point,
@@ -1708,7 +1814,7 @@ update_moved_item_removable_device (TrackerIndexer *indexer,
 							      service_name);
 		}
 	}
-
+#endif
 	g_free (mount_point);
 	g_free (source_path);
 	g_free (path);
@@ -1831,7 +1937,7 @@ item_erase (TrackerIndexer *indexer,
 	schedule_flush (indexer, FALSE);
 }
 
-static void
+static gboolean
 item_move (TrackerIndexer  *indexer,
 	   PathInfo	   *info,
 	   const gchar	   *dirname,
@@ -1847,7 +1953,7 @@ item_move (TrackerIndexer  *indexer,
 	service = get_service_for_file (info->module_file, info->module);
 
 	if (!service) {
-		return;
+		return FALSE;
 	}
 
 	path = g_file_get_path (info->file);
@@ -1861,25 +1967,20 @@ item_move (TrackerIndexer  *indexer,
 						basename,
 						&service_id,
 						NULL)) {
-		TrackerModuleMetadata *metadata;
 		gchar *dest_dirname, *dest_basename;
+		gboolean res;
 
 		g_message ("Source file '%s' not found in database to move, indexing '%s' from scratch", source_path, path);
 
-		metadata = tracker_module_file_get_metadata (info->module_file);
 		tracker_file_get_path_and_name (path, &dest_dirname, &dest_basename);
-
-		if (metadata) {
-			item_add_or_update (indexer, info, dest_dirname, dest_basename, metadata);
-			g_object_unref (metadata);
-		}
+		res = item_process (indexer, info, dest_dirname, dest_basename);
 
 		g_free (dest_dirname);
 		g_free (dest_basename);
 		g_free (path);
 		g_free (source_path);
 
-		return;
+		return res;
 	}
 
 	tracker_file_get_path_and_name (path, &dest_dirname, &dest_basename);
@@ -1916,7 +2017,7 @@ item_move (TrackerIndexer  *indexer,
 			tracker_data_metadata_free (old_metadata);
 		}
 
-		return;
+		return FALSE;
 	}
 
 	/* Update item being moved */
@@ -1957,6 +2058,8 @@ item_move (TrackerIndexer  *indexer,
 
 	g_free (source_path);
 	g_free (path);
+
+	return TRUE;
 }
 
 
@@ -2031,7 +2134,7 @@ item_mark_for_removal (TrackerIndexer *indexer,
 
 		g_hash_table_destroy (children);
 	}
-
+#ifdef HAVE_HAL
 	if (tracker_hal_path_is_on_removable_device (indexer->private->hal,
 						     path, 
 						     &mount_point,
@@ -2041,11 +2144,51 @@ item_mark_for_removal (TrackerIndexer *indexer,
 						      path,
 						      tracker_service_get_name (service));
 	}
-
+#endif
 	g_free (mount_point);
 	g_free (path);
 }
 
+static gboolean
+item_process (TrackerIndexer *indexer,
+	      PathInfo       *info,
+	      const gchar    *dirname,
+	      const gchar    *basename)
+{
+	TrackerModuleMetadata *metadata;
+	gchar *text;
+
+	metadata = tracker_module_file_get_metadata (info->module_file);
+
+	if (tracker_module_file_is_cancelled (info->module_file)) {
+		if (metadata) {
+			g_object_unref (metadata);
+		}
+
+		return FALSE;
+	}
+
+	if (metadata) {
+		text = tracker_module_file_get_text (info->module_file);
+
+		if (tracker_module_file_is_cancelled (info->module_file)) {
+			g_object_unref (metadata);
+			g_free (text);
+
+			return FALSE;
+		}
+
+		item_add_or_update (indexer, info, dirname, basename, metadata, text);
+
+		g_object_unref (metadata);
+		g_free (text);
+	} else {
+		item_mark_for_removal (indexer, info, dirname, basename);
+	}
+
+	return TRUE;
+}
+
 /*
  * TODO: Check how are we using this functions. 
  *       I think 99% of the time "values" has only 1 element.
@@ -2060,8 +2203,8 @@ handle_metadata_add (TrackerIndexer *indexer,
 {
 	TrackerService *service;
 	TrackerField   *field;
-	guint           service_id, i, j = 0;
-	gchar         **setted_values;
+	guint           service_id, i, j;
+	gchar         **set_values;
 	gchar          *joined, *dirname = NULL, *basename = NULL;
 	gchar         **old_contents;
 	gint            len;
@@ -2148,7 +2291,7 @@ handle_metadata_add (TrackerIndexer *indexer,
 		}
 	}
 
-	setted_values = g_new0 (gchar *, g_strv_length (values));
+	set_values = g_new0 (gchar *, g_strv_length (values) + 1);
 
 	for (i = 0, j = 0; values[i] != NULL; i++) {
 		g_debug ("Setting metadata: service_type '%s' id '%d' field '%s' value '%s'",
@@ -2163,11 +2306,10 @@ handle_metadata_add (TrackerIndexer *indexer,
 		}
 
 		tracker_data_update_set_metadata (service, service_id, field, values[i], NULL);
-		setted_values [j++] = values[i];
+		set_values [++j] = values[i];
 	}
-	setted_values [j] = NULL;
-	
-	joined = g_strjoinv (" ", setted_values);
+
+	joined = g_strjoinv (" ", set_values);
 	if (tracker_field_get_filtered (field)) {
 		index_text_no_parsing (indexer,
 				       service_id,
@@ -2187,7 +2329,7 @@ handle_metadata_add (TrackerIndexer *indexer,
 	}
 
 	/* Not g_strfreev because. It contains the pointers of "values"! */
-	g_free (setted_values);
+	g_free (set_values);
 	g_free (joined);
 
 	return TRUE;
@@ -2346,8 +2488,8 @@ should_change_index_for_file (TrackerIndexer *indexer,
 		return TRUE;
 	}
 
-	if (current_mtime <= db_mtime) {
-		g_debug ("'%s' is already up to date in DB, not (re)indexing", path);
+	if (current_mtime == db_mtime) {
+		g_message ("'%s' is already up to date in DB, not (re)indexing", path);
 		g_free (path);
 
 		return FALSE;
@@ -2362,8 +2504,8 @@ static gboolean
 process_file (TrackerIndexer *indexer,
 	      PathInfo	     *info)
 {
-	TrackerModuleMetadata *metadata;
 	gchar *uri, *dirname, *basename;
+	gboolean inc_counters = FALSE;
 
 	/* Note: If info->source_file is set, the PathInfo is for a
 	 * MOVE event not for normal file event.
@@ -2435,26 +2577,26 @@ process_file (TrackerIndexer *indexer,
 	 * a service and set the metadata.
 	 */
 	if (G_UNLIKELY (info->source_file)) {
-		item_move (indexer, info, dirname, basename);
+		if (item_move (indexer, info, dirname, basename)) {
+			inc_counters = TRUE;
+		}
 	} else {
-		metadata = tracker_module_file_get_metadata (info->module_file);
-
-		if (metadata) {
-			item_add_or_update (indexer, info, dirname, basename, metadata);
-			g_object_unref (metadata);
-		} else {
-			item_mark_for_removal (indexer, info, dirname, basename);
+		if (item_process (indexer, info, dirname, basename)) {
+			inc_counters = TRUE;
 		}
 	}
 
-	indexer->private->subelements_processed++;
-	indexer->private->items_processed++;
-	indexer->private->items_to_index++;
+	if (inc_counters) {
+		indexer->private->subelements_processed++;
+		indexer->private->items_processed++;
+		indexer->private->items_to_index++;
+	}
 
 	g_free (dirname);
 	g_free (basename);
 
-	if (TRACKER_IS_MODULE_ITERATABLE (info->module_file)) {
+	if (!tracker_module_file_is_cancelled (info->module_file) &&
+	    TRACKER_IS_MODULE_ITERATABLE (info->module_file)) {
 		return !tracker_module_iteratable_iter_contents (TRACKER_MODULE_ITERATABLE (info->module_file));
 	}
 
