@@ -38,10 +38,10 @@ extern "C" {
 #define ICON_SIZE 40
 #define ICON_THEME_EXECUTABLE_ICON "application-x-executable"
 #define ICON_THEME_REGULAR_ICON    "gnome-fs-regular"
-#define ICON_THEME_CHAR_DEVICE     "gnome-fs-chardev"
+#define ICON_THEME_CHAR_DEVICE	   "gnome-fs-chardev"
 #define ICON_THEME_BLOCK_DEVICE    "gnome-fs-blockdev"
-#define ICON_THEME_SOCKET          "gnome-fs-socket"
-#define ICON_THEME_FIFO            "gnome-fs-fifo"
+#define ICON_THEME_SOCKET	   "gnome-fs-socket"
+#define ICON_THEME_FIFO		   "gnome-fs-fifo"
 
 
 gboolean
@@ -124,31 +124,25 @@ tracker_search_strdup_strftime (const gchar * format,
 				struct tm * time_pieces);
 
 gchar *
-get_file_type_description (const gchar * file,
-			   const char *mime,
-			   GnomeVFSFileInfo * file_info);
+get_file_type_description (GFile * file,
+                           GFileInfo * file_info);
 
 GdkPixbuf *
 get_file_pixbuf (GSearchWindow * gsearch,
-		 const gchar * file,
-		 const char * mime,
-		 GnomeVFSFileInfo * file_info);
+                 GFile * file,
+                 GFileInfo * file_info);
 
 
 gboolean
 open_file_with_xdg_open (GtkWidget * window,
-			 const gchar * file);
+                         GFile * file);
 
 gboolean
 open_file_with_nautilus (GtkWidget * window,
-			 const gchar * file);
+                         GFile * file);
 
 gboolean
-open_file_with_application (GtkWidget * window,
-			    const gchar * file);
-
-gboolean
-launch_file (const gchar * file);
+launch_file (GFile * file);
 
 gchar *
 tracker_search_get_unique_filename (const gchar * path,
@@ -174,6 +168,11 @@ void
 tracker_search_get_stored_window_geometry (gint * width,
 					   gint * height);
 
+void
+tracker_set_atk_relationship (GtkWidget *obj1,
+			      int relation_type,
+			      GtkWidget *obj2);
+
 #ifdef __cplusplus
 }
 #endif
